Installation
============

ESSM is on PyPI so all you need is:

.. code-block:: console

   $ pip install essm

Development
-----------

If you are planning to modify source code or generate new variables
or equations, please install the package in development mode:

.. code-block:: console

   $ git clone https://github.com/environmentalscience/essm
   $ cd environmental-science-for-sagemath
   $ pip install -e .[all]
